@@ -1,8 +1,9 @@
 """Fake Preseem Model implementation."""
 import copy
 import time
-from uuid import uuid4
+from uuid import uuid4, UUID
 
+import grpc
 from preseem.preseem_model import BaseModelObject
 
 class FakePreseemModel:
@@ -33,8 +34,11 @@ class FakePreseemModel:
 
     async def copy_from(self, other, company_uuid):
         """Insert exact copies of entities from another model into this one."""
-        for obj in await other.Company.List():
-            FakePreseemModel._companies[obj.uuid] = obj
+        try:
+            for obj in await other.Company.List():
+                FakePreseemModel._companies[obj.uuid] = obj
+        except grpc.RpcError as err:  # likely permissions, fake this
+            FakePreseemModel._companies[company_uuid] = other.Company(uuid=company_uuid)
         for obj in await other.Element.List(company_uuid=company_uuid):
             elems = FakePreseemModel._elements.get(company_uuid)
             if elems is None:
