@@ -188,14 +188,16 @@ async def sync_elem_discovery(preseem_model,
                             source, uuid)
                         uuid_map[item.id] = uuid
         for disc_uuid in unref_discs:
-            logging.info("sync_elem_discovery(%s): deactivate %s", source,
-                         UUID(bytes=disc_uuid))
-            if not noact:
-                await call_and_log_error(
-                    preseem_model.Element.UpdateElementDiscovery(
-                        company_uuid=company_uuid,
-                        uuid=disc_uuid,
-                        inactive=True))
+            disc = model_discs.get(disc_uuid)
+            if not disc.inactive:
+                logging.info("sync_elem_discovery(%s): deactivate %s", source,
+                             UUID(bytes=disc_uuid))
+                if not noact:
+                    await call_and_log_error(
+                        preseem_model.Element.UpdateElementDiscovery(
+                            company_uuid=company_uuid,
+                            uuid=disc_uuid,
+                            inactive=True))
         return uuid_map
 
 # Old implementation, left here for now
